==> qiho-center-api-2.0.7-sources.jar: com/qiho/center/api/params/account/AccountPageParam.java <==
package com.qiho.center.api.params.account;

import com.qiho.center.api.params.PageQueryParams;

import java.util.List;

/**
 * 账号分页查询参数
 *
 * @author chensong
 * @create 2018-03-30 10:55
 **/
public class AccountPageParam extends PageQueryParams{

    /** 代理商id */
    private Long agentId;

    /** 代理商名称 */
    private String agentName;

    /** 商家id*/
    private Long merchantId;

    /** 商家名称 */
    private String merchantName;

    /** 代理商id列表 */
    private List<Long> agentIdList;

    /** 商家id列表 */
    private List<Long> merchantIdList;

    public List<Long> getAgentIdList() {
        return agentIdList;
    }

    public void setAgentIdList(List<Long> agentIdList) {
        this.agentIdList = agentIdList;
    }

    public List<Long> getMerchantIdList() {
        return merchantIdList;
    }

    public void setMerchantIdList(List<Long> merchantIdList) {
        this.merchantIdList = merchantIdList;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }
}

==> qiho-center-api-2.3.89-20200605.021058-5-sources.jar: com/qiho/center/api/params/account/AccountPageParam.java <==
package com.qiho.center.api.params.account;

import com.qiho.center.api.params.PageQueryParams;

import java.util.List;

/**
 * 账号分页查询参数
 *
 * @author chensong
 * @create 2018-03-30 10:55
 **/
public class AccountPageParam extends PageQueryParams{

    /** 代理商id */
    private Long agentId;

    /** 代理商名称 */
    private String agentName;

    /** 商家id*/
    private Long merchantId;

    /** 商家名称 */
    private String merchantName;

    /** 代理商id列表 */
    private List<Long> agentIdList;

    /** 商家id列表 */
    private List<Long> merchantIdList;

    /**
     * 联系电话
     */
    private String phone;

    public List<Long> getAgentIdList() {
        return agentIdList;
    }

    public void setAgentIdList(List<Long> agentIdList) {
        this.agentIdList = agentIdList;
    }

    public List<Long> getMerchantIdList() {
        return merchantIdList;
    }

    public void setMerchantIdList(List<Long> merchantIdList) {
        this.merchantIdList = merchantIdList;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
}
